# coding: utf-8

"""
    Conekta API

    Conekta sdk

    The version of the OpenAPI document: 2.2.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from conekta.api.companies_api import CompaniesApi


class TestCompaniesApi(unittest.TestCase):
    """CompaniesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CompaniesApi()

    def tearDown(self) -> None:
        pass

    def test_create_company(self) -> None:
        """Test case for create_company

        Create Company
        """
        pass

    def test_get_companies(self) -> None:
        """Test case for get_companies

        Get List of Companies
        """
        pass

    def test_get_company(self) -> None:
        """Test case for get_company

        Get Company
        """
        pass

    def test_get_company_documents(self) -> None:
        """Test case for get_company_documents

        Get Company Documents
        """
        pass

    def test_update_company_document(self) -> None:
        """Test case for update_company_document

        Update Company Document
        """
        pass

    def test_upload_company_document(self) -> None:
        """Test case for upload_company_document

        Upload Company Document
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Conekta API

    Conekta sdk

    The version of the OpenAPI document: 2.2.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from conekta.api.antifraud_api import AntifraudApi


class TestAntifraudApi(unittest.TestCase):
    """AntifraudApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AntifraudApi()

    def tearDown(self) -> None:
        pass

    def test_create_rule_blacklist(self) -> None:
        """Test case for create_rule_blacklist

        Create blacklisted rule
        """
        pass

    def test_create_rule_whitelist(self) -> None:
        """Test case for create_rule_whitelist

        Create whitelisted rule
        """
        pass

    def test_delete_rule_blacklist(self) -> None:
        """Test case for delete_rule_blacklist

        Delete blacklisted rule
        """
        pass

    def test_delete_rule_whitelist(self) -> None:
        """Test case for delete_rule_whitelist

        Delete whitelisted rule
        """
        pass

    def test_get_rule_blacklist(self) -> None:
        """Test case for get_rule_blacklist

        Get list of blacklisted rules
        """
        pass

    def test_get_rule_whitelist(self) -> None:
        """Test case for get_rule_whitelist

        Get a list of whitelisted rules
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Conekta API

    Conekta sdk

    The version of the OpenAPI document: 2.2.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from conekta.api.payment_link_api import PaymentLinkApi


class TestPaymentLinkApi(unittest.TestCase):
    """PaymentLinkApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PaymentLinkApi()

    def tearDown(self) -> None:
        pass

    def test_cancel_checkout(self) -> None:
        """Test case for cancel_checkout

        Cancel Payment Link
        """
        pass

    def test_create_checkout(self) -> None:
        """Test case for create_checkout

        Create Unique Payment Link
        """
        pass

    def test_email_checkout(self) -> None:
        """Test case for email_checkout

        Send an email
        """
        pass

    def test_get_checkout(self) -> None:
        """Test case for get_checkout

        Get a payment link by ID
        """
        pass

    def test_get_checkouts(self) -> None:
        """Test case for get_checkouts

        Get a list of payment links
        """
        pass

    def test_sms_checkout(self) -> None:
        """Test case for sms_checkout

        Send an sms
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Conekta API

    Conekta sdk

    The version of the OpenAPI document: 2.2.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from conekta.models.company_response_documents_inner import CompanyResponseDocumentsInner
from typing import Optional, Set
from typing_extensions import Self

class CompanyResponse(BaseModel):
    """
    CompanyResponse
    """ # noqa: E501
    id: StrictStr = Field(description="The unique identifier for the company.")
    name: StrictStr = Field(description="The name of the company.")
    active: StrictBool = Field(description="Indicates if the company is active.")
    account_status: StrictStr = Field(description="The current status of the company's account.")
    parent_company_id: Optional[StrictStr] = Field(default=None, description="The identifier of the parent company, if any.")
    onboarding_status: StrictStr = Field(description="The current status of the company's onboarding process.")
    documents: List[CompanyResponseDocumentsInner] = Field(description="A list of documents related to the company.")
    created_at: StrictInt = Field(description="Timestamp of when the company was created.")
    object: StrictStr = Field(description="The type of object, typically \"company\".")
    __properties: ClassVar[List[str]] = ["id", "name", "active", "account_status", "parent_company_id", "onboarding_status", "documents", "created_at", "object"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CompanyResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in documents (list)
        _items = []
        if self.documents:
            for _item_documents in self.documents:
                if _item_documents:
                    _items.append(_item_documents.to_dict())
            _dict['documents'] = _items
        # set to None if parent_company_id (nullable) is None
        # and model_fields_set contains the field
        if self.parent_company_id is None and "parent_company_id" in self.model_fields_set:
            _dict['parent_company_id'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CompanyResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "active": obj.get("active"),
            "account_status": obj.get("account_status"),
            "parent_company_id": obj.get("parent_company_id"),
            "onboarding_status": obj.get("onboarding_status"),
            "documents": [CompanyResponseDocumentsInner.from_dict(_item) for _item in obj["documents"]] if obj.get("documents") is not None else None,
            "created_at": obj.get("created_at"),
            "object": obj.get("object")
        })
        return _obj





# coding: utf-8

"""
    Conekta API

    Conekta sdk

    The version of the OpenAPI document: 2.2.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from conekta.api.shipping_contacts_api import ShippingContactsApi


class TestShippingContactsApi(unittest.TestCase):
    """ShippingContactsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ShippingContactsApi()

    def tearDown(self) -> None:
        pass

    def test_create_customer_shipping_contacts(self) -> None:
        """Test case for create_customer_shipping_contacts

        Create a shipping contacts
        """
        pass

    def test_delete_customer_shipping_contacts(self) -> None:
        """Test case for delete_customer_shipping_contacts

        Delete shipping contacts
        """
        pass

    def test_update_customer_shipping_contacts(self) -> None:
        """Test case for update_customer_shipping_contacts

        Update shipping contacts
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Conekta API

    Conekta sdk

    The version of the OpenAPI document: 2.2.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class TransactionResponse(BaseModel):
    """
    The Transaction object represents the actions or steps of an order. Statuses can be: unprocessed, pending, available, owen, paid_out, voided, capture, capture_reversal, liquidation, liquidation_reversal, payout, payout_reversal, refund, refund_reversal, chargeback, chargeback_reversal, rounding_adjustment, won_chargeback, transferred, and transferred.
    """ # noqa: E501
    amount: StrictInt = Field(description="The amount of the transaction.")
    charge: StrictStr = Field(description="Randomly assigned unique order identifier associated with the charge.")
    created_at: StrictInt = Field(description="Date and time of creation of the transaction in Unix format.")
    currency: Annotated[str, Field(strict=True, max_length=3)] = Field(description="The currency of the transaction. It uses the 3-letter code of the [International Standard ISO 4217.](https://es.wikipedia.org/wiki/ISO_4217)")
    fee: StrictInt = Field(description="The amount to be deducted for taxes and commissions.")
    id: StrictStr = Field(description="Unique identifier of the transaction.")
    livemode: StrictBool = Field(description="Indicates whether the transaction was created in live mode or test mode.")
    net: StrictInt = Field(description="The net amount after deducting commissions and taxes.")
    object: StrictStr = Field(description="Object name, which is transaction.")
    status: StrictStr = Field(description="Code indicating transaction status.")
    type: StrictStr = Field(description="Transaction Type")
    __properties: ClassVar[List[str]] = ["amount", "charge", "created_at", "currency", "fee", "id", "livemode", "net", "object", "status", "type"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TransactionResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TransactionResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "amount": obj.get("amount"),
            "charge": obj.get("charge"),
            "created_at": obj.get("created_at"),
            "currency": obj.get("currency"),
            "fee": obj.get("fee"),
            "id": obj.get("id"),
            "livemode": obj.get("livemode"),
            "net": obj.get("net"),
            "object": obj.get("object"),
            "status": obj.get("status"),
            "type": obj.get("type")
        })
        return _obj





# coding: utf-8

# flake8: noqa

"""
    Conekta API

    Conekta sdk

    The version of the OpenAPI document: 2.2.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "7.0.2"

# import apis into sdk package
from conekta.api.antifraud_api import AntifraudApi
from conekta.api.api_keys_api import ApiKeysApi
from conekta.api.balances_api import BalancesApi
from conekta.api.charges_api import ChargesApi
from conekta.api.companies_api import CompaniesApi
from conekta.api.customers_api import CustomersApi
from conekta.api.discounts_api import DiscountsApi
from conekta.api.events_api import EventsApi
from conekta.api.logs_api import LogsApi
from conekta.api.orders_api import OrdersApi
from conekta.api.payment_link_api import PaymentLinkApi
from conekta.api.payment_methods_api import PaymentMethodsApi
from conekta.api.payout_orders_api import PayoutOrdersApi
from conekta.api.plans_api import PlansApi
from conekta.api.products_api import ProductsApi
from conekta.api.shipping_contacts_api import ShippingContactsApi
from conekta.api.shippings_api import ShippingsApi
from conekta.api.subscriptions_api import SubscriptionsApi
from conekta.api.taxes_api import TaxesApi
from conekta.api.tokens_api import TokensApi
from conekta.api.transactions_api import TransactionsApi
from conekta.api.transfers_api import TransfersApi
from conekta.api.webhook_keys_api import WebhookKeysApi
from conekta.api.webhooks_api import WebhooksApi

# import ApiClient
from conekta.api_response import ApiResponse
from conekta.api_client import ApiClient
from conekta.configuration import Configuration
from conekta.exceptions import OpenApiException
from conekta.exceptions import ApiTypeError
from conekta.exceptions import ApiValueError
from conekta.exceptions import ApiKeyError
from conekta.exceptions import ApiAttributeError
from conekta.exceptions import ApiException

# import models into sdk package
from conekta.models.api_key_create_response import ApiKeyCreateResponse
from conekta.models.api_key_request import ApiKeyRequest
from conekta.models.api_key_response import ApiKeyResponse
from conekta.models.api_key_response_on_delete import ApiKeyResponseOnDelete
from conekta.models.api_key_update_request import ApiKeyUpdateRequest
from conekta.models.balance_common_field import BalanceCommonField
from conekta.models.balance_response import BalanceResponse
from conekta.models.blacklist_rule_response import BlacklistRuleResponse
from conekta.models.charge_order_response import ChargeOrderResponse
from conekta.models.charge_order_response_payment_method import ChargeOrderResponsePaymentMethod
from conekta.models.charge_request import ChargeRequest
from conekta.models.charge_request_payment_method import ChargeRequestPaymentMethod
from conekta.models.charge_response import ChargeResponse
from conekta.models.charge_response_channel import ChargeResponseChannel
from conekta.models.charge_response_payment_method import ChargeResponsePaymentMethod
from conekta.models.charge_response_refunds import ChargeResponseRefunds
from conekta.models.charge_response_refunds_data import ChargeResponseRefundsData
from conekta.models.charge_update_request import ChargeUpdateRequest
from conekta.models.charges_data_response import ChargesDataResponse
from conekta.models.charges_order_response import ChargesOrderResponse
from conekta.models.charges_order_response_all_of_data import ChargesOrderResponseAllOfData
from conekta.models.checkout import Checkout
from conekta.models.checkout_order_template import CheckoutOrderTemplate
from conekta.models.checkout_order_template_customer_info import CheckoutOrderTemplateCustomerInfo
from conekta.models.checkout_request import CheckoutRequest
from conekta.models.checkout_response import CheckoutResponse
from conekta.models.checkouts_response import CheckoutsResponse
from conekta.models.company_document_request import CompanyDocumentRequest
from conekta.models.company_document_response import CompanyDocumentResponse
from conekta.models.company_response import CompanyResponse
from conekta.models.company_response_documents_inner import CompanyResponseDocumentsInner
from conekta.models.create_company_request import CreateCompanyRequest
from conekta.models.create_company_request_bank_account_info import CreateCompanyRequestBankAccountInfo
from conekta.models.create_company_request_comercial_info import CreateCompanyRequestComercialInfo
from conekta.models.create_company_request_fiscal_info import CreateCompanyRequestFiscalInfo
from conekta.models.create_customer_fiscal_entities_response import CreateCustomerFiscalEntitiesResponse
from conekta.models.create_customer_payment_methods_request import CreateCustomerPaymentMethodsRequest
from conekta.models.create_customer_payment_methods_response import CreateCustomerPaymentMethodsResponse
from conekta.models.create_risk_rules_data import CreateRiskRulesData
from conekta.models.customer import Customer
from conekta.models.customer_address import CustomerAddress
from conekta.models.customer_antifraud_info import CustomerAntifraudInfo
from conekta.models.customer_antifraud_info_response import CustomerAntifraudInfoResponse
from conekta.models.customer_fiscal_entities_data_response import CustomerFiscalEntitiesDataResponse
from conekta.models.customer_fiscal_entities_request import CustomerFiscalEntitiesRequest
from conekta.models.customer_fiscal_entities_response import CustomerFiscalEntitiesResponse
from conekta.models.customer_info import CustomerInfo
from conekta.models.customer_info_just_customer_id import CustomerInfoJustCustomerId
from conekta.models.customer_info_just_customer_id_response import CustomerInfoJustCustomerIdResponse
from conekta.models.customer_payment_method_request import CustomerPaymentMethodRequest
from conekta.models.customer_payment_methods_data import CustomerPaymentMethodsData
from conekta.models.customer_payment_methods_request import CustomerPaymentMethodsRequest
from conekta.models.customer_payment_methods_response import CustomerPaymentMethodsResponse
from conekta.models.customer_response import CustomerResponse
from conekta.models.customer_response_shipping_contacts import CustomerResponseShippingContacts
from conekta.models.customer_shipping_contacts import CustomerShippingContacts
from conekta.models.customer_shipping_contacts_address import CustomerShippingContactsAddress
from conekta.models.customer_shipping_contacts_data_response import CustomerShippingContactsDataResponse
from conekta.models.customer_shipping_contacts_response import CustomerShippingContactsResponse
from conekta.models.customer_shipping_contacts_response_address import CustomerShippingContactsResponseAddress
from conekta.models.customer_update_fiscal_entities_request import CustomerUpdateFiscalEntitiesRequest
from conekta.models.customer_update_shipping_contacts import CustomerUpdateShippingContacts
from conekta.models.customers_response import CustomersResponse
from conekta.models.delete_api_keys_response import DeleteApiKeysResponse
from conekta.models.deleted_blacklist_rule_response import DeletedBlacklistRuleResponse
from conekta.models.deleted_whitelist_rule_response import DeletedWhitelistRuleResponse
from conekta.models.details import Details
from conekta.models.details_error import DetailsError
from conekta.models.discount_lines_data_response import DiscountLinesDataResponse
from conekta.models.discount_lines_response import DiscountLinesResponse
from conekta.models.email_checkout_request import EmailCheckoutRequest
from conekta.models.error import Error
from conekta.models.event_response import EventResponse
from conekta.models.event_types import EventTypes
from conekta.models.events_resend_response import EventsResendResponse
from conekta.models.fiscal_entity_address import FiscalEntityAddress
from conekta.models.get_api_keys_response import GetApiKeysResponse
from conekta.models.get_charges_response import GetChargesResponse
from conekta.models.get_companies_response import GetCompaniesResponse
from conekta.models.get_customer_payment_method_data_response import GetCustomerPaymentMethodDataResponse
from conekta.models.get_events_response import GetEventsResponse
from conekta.models.get_order_discount_lines_response import GetOrderDiscountLinesResponse
from conekta.models.get_orders_response import GetOrdersResponse
from conekta.models.get_payment_method_response import GetPaymentMethodResponse
from conekta.models.get_plans_response import GetPlansResponse
from conekta.models.get_transactions_response import GetTransactionsResponse
from conekta.models.get_transfers_response import GetTransfersResponse
from conekta.models.get_webhook_keys_response import GetWebhookKeysResponse
from conekta.models.get_webhooks_response import GetWebhooksResponse
from conekta.models.log_response import LogResponse
from conekta.models.logs_response import LogsResponse
from conekta.models.logs_response_data import LogsResponseData
from conekta.models.order_capture_request import OrderCaptureRequest
from conekta.models.order_channel_response import OrderChannelResponse
from conekta.models.order_charges_response import OrderChargesResponse
from conekta.models.order_customer_info_response import OrderCustomerInfoResponse
from conekta.models.order_discount_lines_request import OrderDiscountLinesRequest
from conekta.models.order_discount_lines_response import OrderDiscountLinesResponse
from conekta.models.order_fiscal_entity_address_response import OrderFiscalEntityAddressResponse
from conekta.models.order_fiscal_entity_request import OrderFiscalEntityRequest
from conekta.models.order_fiscal_entity_response import OrderFiscalEntityResponse
from conekta.models.order_next_action_response import OrderNextActionResponse
from conekta.models.order_next_action_response_redirect_to_url import OrderNextActionResponseRedirectToUrl
from conekta.models.order_refund_request import OrderRefundRequest
from conekta.models.order_request import OrderRequest
from conekta.models.order_request_customer_info import OrderRequestCustomerInfo
from conekta.models.order_response import OrderResponse
from conekta.models.order_response_checkout import OrderResponseCheckout
from conekta.models.order_response_customer_info import OrderResponseCustomerInfo
from conekta.models.order_response_products import OrderResponseProducts
from conekta.models.order_response_shipping_contact import OrderResponseShippingContact
from conekta.models.order_tax_request import OrderTaxRequest
from conekta.models.order_update_fiscal_entity_request import OrderUpdateFiscalEntityRequest
from conekta.models.order_update_request import OrderUpdateRequest
from conekta.models.order_update_request_customer_info import OrderUpdateRequestCustomerInfo
from conekta.models.orders_response import OrdersResponse
from conekta.models.page import Page
from conekta.models.pagination import Pagination
from conekta.models.payment_method import PaymentMethod
from conekta.models.payment_method_bank_transfer import PaymentMethodBankTransfer
from conekta.models.payment_method_bnpl_payment import PaymentMethodBnplPayment
from conekta.models.payment_method_bnpl_request import PaymentMethodBnplRequest
from conekta.models.payment_method_card import PaymentMethodCard
from conekta.models.payment_method_card_request import PaymentMethodCardRequest
from conekta.models.payment_method_card_response import PaymentMethodCardResponse
from conekta.models.payment_method_cash import PaymentMethodCash
from conekta.models.payment_method_cash_request import PaymentMethodCashRequest
from conekta.models.payment_method_cash_response import PaymentMethodCashResponse
from conekta.models.payment_method_cash_response_all_of_agreements import PaymentMethodCashResponseAllOfAgreements
from conekta.models.payment_method_general_request import PaymentMethodGeneralRequest
from conekta.models.payment_method_response import PaymentMethodResponse
from conekta.models.payment_method_spei_recurrent import PaymentMethodSpeiRecurrent
from conekta.models.payment_method_spei_request import PaymentMethodSpeiRequest
from conekta.models.payment_method_token_request import PaymentMethodTokenRequest
from conekta.models.payout import Payout
from conekta.models.payout_method import PayoutMethod
from conekta.models.payout_order import PayoutOrder
from conekta.models.payout_order_payouts_item import PayoutOrderPayoutsItem
from conekta.models.payout_order_response import PayoutOrderResponse
from conekta.models.payout_order_response_customer_info import PayoutOrderResponseCustomerInfo
from conekta.models.payout_orders_response import PayoutOrdersResponse
from conekta.models.plan_request import PlanRequest
from conekta.models.plan_response import PlanResponse
from conekta.models.plan_update_request import PlanUpdateRequest
from conekta.models.product import Product
from conekta.models.product_data_response import ProductDataResponse
from conekta.models.product_order_response import ProductOrderResponse
from conekta.models.resend_request import ResendRequest
from conekta.models.risk_rules_data import RiskRulesData
from conekta.models.risk_rules_list import RiskRulesList
from conekta.models.shipping_order_response import ShippingOrderResponse
from conekta.models.shipping_request import ShippingRequest
from conekta.models.sms_checkout_request import SmsCheckoutRequest
from conekta.models.subscription_events_response import SubscriptionEventsResponse
from conekta.models.subscription_request import SubscriptionRequest
from conekta.models.subscription_response import SubscriptionResponse
from conekta.models.subscription_update_request import SubscriptionUpdateRequest
from conekta.models.token import Token
from conekta.models.token_card import TokenCard
from conekta.models.token_checkout import TokenCheckout
from conekta.models.token_response import TokenResponse
from conekta.models.token_response_checkout import TokenResponseCheckout
from conekta.models.transaction_response import TransactionResponse
from conekta.models.transfer_destination_response import TransferDestinationResponse
from conekta.models.transfer_method_response import TransferMethodResponse
from conekta.models.transfer_response import TransferResponse
from conekta.models.transfers_response import TransfersResponse
from conekta.models.update_customer import UpdateCustomer
from conekta.models.update_customer_antifraud_info import UpdateCustomerAntifraudInfo
from conekta.models.update_customer_fiscal_entities_response import UpdateCustomerFiscalEntitiesResponse
from conekta.models.update_customer_payment_methods_response import UpdateCustomerPaymentMethodsResponse
from conekta.models.update_order_discount_lines_request import UpdateOrderDiscountLinesRequest
from conekta.models.update_order_tax_request import UpdateOrderTaxRequest
from conekta.models.update_order_tax_response import UpdateOrderTaxResponse
from conekta.models.update_payment_methods import UpdatePaymentMethods
from conekta.models.update_product import UpdateProduct
from conekta.models.webhook_key_create_response import WebhookKeyCreateResponse
from conekta.models.webhook_key_delete_response import WebhookKeyDeleteResponse
from conekta.models.webhook_key_request import WebhookKeyRequest
from conekta.models.webhook_key_response import WebhookKeyResponse
from conekta.models.webhook_key_update_request import WebhookKeyUpdateRequest
from conekta.models.webhook_log import WebhookLog
from conekta.models.webhook_request import WebhookRequest
from conekta.models.webhook_response import WebhookResponse
from conekta.models.webhook_update_request import WebhookUpdateRequest
from conekta.models.whitelistlist_rule_response import WhitelistlistRuleResponse



# coding: utf-8

"""
    Conekta API

    Conekta sdk

    The version of the OpenAPI document: 2.2.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from conekta.api.subscriptions_api import SubscriptionsApi


class TestSubscriptionsApi(unittest.TestCase):
    """SubscriptionsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SubscriptionsApi()

    def tearDown(self) -> None:
        pass

    def test_cancel_subscription(self) -> None:
        """Test case for cancel_subscription

        Cancel Subscription [Deprecated]
        """
        pass

    def test_create_subscription(self) -> None:
        """Test case for create_subscription

        Create Subscription [Deprecated]
        """
        pass

    def test_get_subscription(self) -> None:
        """Test case for get_subscription

        Get Subscription [Deprecated]
        """
        pass

    def test_get_subscription_events(self) -> None:
        """Test case for get_subscription_events

        Get Subscription Events [Deprecated]
        """
        pass

    def test_pause_subscription(self) -> None:
        """Test case for pause_subscription

        Pause Subscription [Deprecated]
        """
        pass

    def test_resume_subscription(self) -> None:
        """Test case for resume_subscription

        Resume Subscription [Deprecated]
        """
        pass

    def test_subscription_cancel(self) -> None:
        """Test case for subscription_cancel

        Cancel Subscription
        """
        pass

    def test_subscription_create(self) -> None:
        """Test case for subscription_create

        Create Subscription
        """
        pass

    def test_subscription_events(self) -> None:
        """Test case for subscription_events

        Get Subscription Events
        """
        pass

    def test_subscription_list(self) -> None:
        """Test case for subscription_list

        List Subscriptions
        """
        pass

    def test_subscription_pause(self) -> None:
        """Test case for subscription_pause

        Pause Subscription
        """
        pass

    def test_subscription_resume(self) -> None:
        """Test case for subscription_resume

        Resume Subscription
        """
        pass

    def test_subscription_update(self) -> None:
        """Test case for subscription_update

        Update Subscription
        """
        pass

    def test_subscriptions_get(self) -> None:
        """Test case for subscriptions_get

        Get Subscription
        """
        pass

    def test_subscriptions_retry(self) -> None:
        """Test case for subscriptions_retry

        Retry Failed Payment
        """
        pass

    def test_update_subscription(self) -> None:
        """Test case for update_subscription

        Update Subscription [Deprecated]
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Conekta API

    Conekta sdk

    The version of the OpenAPI document: 2.2.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from conekta.models.checkout_order_template import CheckoutOrderTemplate
from typing import Optional, Set
from typing_extensions import Self

class Checkout(BaseModel):
    """
    It is a sub-resource of the Order model that can be stipulated in order to configure its corresponding checkout
    """ # noqa: E501
    allowed_payment_methods: List[StrictStr] = Field(description="Those are the payment methods that will be available for the link")
    expires_at: StrictInt = Field(description="It is the time when the link will expire. It is expressed in seconds since the Unix epoch. The valid range is from 2 to 365 days (the valid range will be taken from the next day of the creation date at 00:01 hrs) ")
    monthly_installments_enabled: Optional[StrictBool] = Field(default=None, description="This flag allows you to specify if months without interest will be active.")
    monthly_installments_options: Optional[List[StrictInt]] = Field(default=None, description="This field allows you to specify the number of months without interest.")
    three_ds_mode: Optional[StrictStr] = Field(default=None, description="Indicates the 3DS2 mode for the order, either smart or strict.")
    name: StrictStr = Field(description="Reason for charge")
    needs_shipping_contact: Optional[StrictBool] = Field(default=None, description="This flag allows you to fill in the shipping information at checkout.")
    on_demand_enabled: Optional[StrictBool] = Field(default=None, description="This flag allows you to specify if the link will be on demand.")
    order_template: CheckoutOrderTemplate
    payments_limit_count: Optional[StrictInt] = Field(default=None, description="It is the number of payments that can be made through the link.")
    recurrent: StrictBool = Field(description="false: single use. true: multiple payments")
    type: StrictStr = Field(description="It is the type of link that will be created. It must be a valid type.")
    __properties: ClassVar[List[str]] = ["allowed_payment_methods", "expires_at", "monthly_installments_enabled", "monthly_installments_options", "three_ds_mode", "name", "needs_shipping_contact", "on_demand_enabled", "order_template", "payments_limit_count", "recurrent", "type"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Checkout from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of order_template
        if self.order_template:
            _dict['order_template'] = self.order_template.to_dict()
        # set to None if on_demand_enabled (nullable) is None
        # and model_fields_set contains the field
        if self.on_demand_enabled is None and "on_demand_enabled" in self.model_fields_set:
            _dict['on_demand_enabled'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Checkout from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "allowed_payment_methods": obj.get("allowed_payment_methods"),
            "expires_at": obj.get("expires_at"),
            "monthly_installments_enabled": obj.get("monthly_installments_enabled"),
            "monthly_installments_options": obj.get("monthly_installments_options"),
            "three_ds_mode": obj.get("three_ds_mode"),
            "name": obj.get("name"),
            "needs_shipping_contact": obj.get("needs_shipping_contact"),
            "on_demand_enabled": obj.get("on_demand_enabled"),
            "order_template": CheckoutOrderTemplate.from_dict(obj["order_template"]) if obj.get("order_template") is not None else None,
            "payments_limit_count": obj.get("payments_limit_count"),
            "recurrent": obj.get("recurrent"),
            "type": obj.get("type")
        })
        return _obj





# coding: utf-8

"""
    Conekta API

    Conekta sdk

    The version of the OpenAPI document: 2.2.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from conekta.models.balance_common_field import BalanceCommonField
from typing import Optional, Set
from typing_extensions import Self

class BalanceResponse(BaseModel):
    """
    balance model
    """ # noqa: E501
    available: Optional[List[BalanceCommonField]] = Field(default=None, description="The balance's available")
    cashout_retention_amount: Optional[List[BalanceCommonField]] = Field(default=None, description="The balance's cashout retention amount")
    conekta_retention: Optional[List[BalanceCommonField]] = Field(default=None, description="The balance's conekta retention")
    gateway: Optional[List[BalanceCommonField]] = Field(default=None, description="The balance's gateway")
    pending: Optional[List[BalanceCommonField]] = Field(default=None, description="The balance's pending")
    retained: Optional[List[BalanceCommonField]] = Field(default=None, description="The balance's retained")
    retention_amount: Optional[List[BalanceCommonField]] = Field(default=None, description="The balance's retention amount")
    target_collateral_amount: Optional[Dict[str, Any]] = Field(default=None, description="The balance's target collateral amount")
    target_retention_amount: Optional[List[BalanceCommonField]] = Field(default=None, description="The balance's target retention amount")
    temporarily_retained: Optional[List[BalanceCommonField]] = Field(default=None, description="The balance's temporarily retained")
    __properties: ClassVar[List[str]] = ["available", "cashout_retention_amount", "conekta_retention", "gateway", "pending", "retained", "retention_amount", "target_collateral_amount", "target_retention_amount", "temporarily_retained"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of BalanceResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in available (list)
        _items = []
        if self.available:
            for _item_available in self.available:
                if _item_available:
                    _items.append(_item_available.to_dict())
            _dict['available'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in cashout_retention_amount (list)
        _items = []
        if self.cashout_retention_amount:
            for _item_cashout_retention_amount in self.cashout_retention_amount:
                if _item_cashout_retention_amount:
                    _items.append(_item_cashout_retention_amount.to_dict())
            _dict['cashout_retention_amount'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in conekta_retention (list)
        _items = []
        if self.conekta_retention:
            for _item_conekta_retention in self.conekta_retention:
                if _item_conekta_retention:
                    _items.append(_item_conekta_retention.to_dict())
            _dict['conekta_retention'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in gateway (list)
        _items = []
        if self.gateway:
            for _item_gateway in self.gateway:
                if _item_gateway:
                    _items.append(_item_gateway.to_dict())
            _dict['gateway'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in pending (list)
        _items = []
        if self.pending:
            for _item_pending in self.pending:
                if _item_pending:
                    _items.append(_item_pending.to_dict())
            _dict['pending'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in retained (list)
        _items = []
        if self.retained:
            for _item_retained in self.retained:
                if _item_retained:
                    _items.append(_item_retained.to_dict())
            _dict['retained'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in retention_amount (list)
        _items = []
        if self.retention_amount:
            for _item_retention_amount in self.retention_amount:
                if _item_retention_amount:
                    _items.append(_item_retention_amount.to_dict())
            _dict['retention_amount'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in target_retention_amount (list)
        _items = []
        if self.target_retention_amount:
            for _item_target_retention_amount in self.target_retention_amount:
                if _item_target_retention_amount:
                    _items.append(_item_target_retention_amount.to_dict())
            _dict['target_retention_amount'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in temporarily_retained (list)
        _items = []
        if self.temporarily_retained:
            for _item_temporarily_retained in self.temporarily_retained:
                if _item_temporarily_retained:
                    _items.append(_item_temporarily_retained.to_dict())
            _dict['temporarily_retained'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of BalanceResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "available": [BalanceCommonField.from_dict(_item) for _item in obj["available"]] if obj.get("available") is not None else None,
            "cashout_retention_amount": [BalanceCommonField.from_dict(_item) for _item in obj["cashout_retention_amount"]] if obj.get("cashout_retention_amount") is not None else None,
            "conekta_retention": [BalanceCommonField.from_dict(_item) for _item in obj["conekta_retention"]] if obj.get("conekta_retention") is not None else None,
            "gateway": [BalanceCommonField.from_dict(_item) for _item in obj["gateway"]] if obj.get("gateway") is not None else None,
            "pending": [BalanceCommonField.from_dict(_item) for _item in obj["pending"]] if obj.get("pending") is not None else None,
            "retained": [BalanceCommonField.from_dict(_item) for _item in obj["retained"]] if obj.get("retained") is not None else None,
            "retention_amount": [BalanceCommonField.from_dict(_item) for _item in obj["retention_amount"]] if obj.get("retention_amount") is not None else None,
            "target_collateral_amount": obj.get("target_collateral_amount"),
            "target_retention_amount": [BalanceCommonField.from_dict(_item) for _item in obj["target_retention_amount"]] if obj.get("target_retention_amount") is not None else None,
            "temporarily_retained": [BalanceCommonField.from_dict(_item) for _item in obj["temporarily_retained"]] if obj.get("temporarily_retained") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Conekta API

    Conekta sdk

    The version of the OpenAPI document: 2.2.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class EventTypes(str, Enum):
    """
    It is a parameter that allows to identify in the response, the type of event that is being generated.
    """

    """
    allowed enum values
    """
    WEBHOOK_PING = 'webhook_ping'
    ORDER_DOT_PAID = 'order.paid'
    ORDER_DOT_EXPIRED = 'order.expired'
    ORDER_DOT_CANCELED = 'order.canceled'
    ORDER_DOT_PENDING_PAYMENT = 'order.pending_payment'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of EventTypes from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Conekta API

    Conekta sdk

    The version of the OpenAPI document: 2.2.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from conekta.models.charge_response_channel import ChargeResponseChannel
from conekta.models.charge_response_payment_method import ChargeResponsePaymentMethod
from conekta.models.charge_response_refunds import ChargeResponseRefunds
from typing import Optional, Set
from typing_extensions import Self

class ChargesOrderResponseAllOfData(BaseModel):
    """
    ChargesOrderResponseAllOfData
    """ # noqa: E501
    amount: StrictInt
    channel: Optional[ChargeResponseChannel] = None
    created_at: StrictInt
    currency: StrictStr
    customer_id: Optional[StrictStr] = None
    description: Optional[StrictStr] = None
    device_fingerprint: Optional[StrictStr] = None
    failure_code: Optional[StrictStr] = None
    failure_message: Optional[StrictStr] = None
    id: StrictStr = Field(description="Charge ID")
    livemode: StrictBool = Field(description="Whether the charge was made in live mode or not")
    object: StrictStr
    order_id: StrictStr = Field(description="Order ID")
    paid_at: Optional[StrictInt] = Field(default=None, description="Payment date")
    payment_method: Optional[ChargeResponsePaymentMethod] = None
    reference_id: Optional[StrictStr] = Field(default=None, description="Reference ID of the charge")
    refunds: Optional[ChargeResponseRefunds] = None
    status: StrictStr = Field(description="Charge status")
    __properties: ClassVar[List[str]] = ["amount", "channel", "created_at", "currency", "customer_id", "description", "device_fingerprint", "failure_code", "failure_message", "id", "livemode", "object", "order_id", "paid_at", "payment_method", "reference_id", "refunds", "status"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ChargesOrderResponseAllOfData from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of channel
        if self.channel:
            _dict['channel'] = self.channel.to_dict()
        # override the default output from pydantic by calling `to_dict()` of payment_method
        if self.payment_method:
            _dict['payment_method'] = self.payment_method.to_dict()
        # override the default output from pydantic by calling `to_dict()` of refunds
        if self.refunds:
            _dict['refunds'] = self.refunds.to_dict()
        # set to None if paid_at (nullable) is None
        # and model_fields_set contains the field
        if self.paid_at is None and "paid_at" in self.model_fields_set:
            _dict['paid_at'] = None

        # set to None if reference_id (nullable) is None
        # and model_fields_set contains the field
        if self.reference_id is None and "reference_id" in self.model_fields_set:
            _dict['reference_id'] = None

        # set to None if refunds (nullable) is None
        # and model_fields_set contains the field
        if self.refunds is None and "refunds" in self.model_fields_set:
            _dict['refunds'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ChargesOrderResponseAllOfData from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "amount": obj.get("amount"),
            "channel": ChargeResponseChannel.from_dict(obj["channel"]) if obj.get("channel") is not None else None,
            "created_at": obj.get("created_at"),
            "currency": obj.get("currency"),
            "customer_id": obj.get("customer_id"),
            "description": obj.get("description"),
            "device_fingerprint": obj.get("device_fingerprint"),
            "failure_code": obj.get("failure_code"),
            "failure_message": obj.get("failure_message"),
            "id": obj.get("id"),
            "livemode": obj.get("livemode"),
            "object": obj.get("object"),
            "order_id": obj.get("order_id"),
            "paid_at": obj.get("paid_at"),
            "payment_method": ChargeResponsePaymentMethod.from_dict(obj["payment_method"]) if obj.get("payment_method") is not None else None,
            "reference_id": obj.get("reference_id"),
            "refunds": ChargeResponseRefunds.from_dict(obj["refunds"]) if obj.get("refunds") is not None else None,
            "status": obj.get("status")
        })
        return _obj





# coding: utf-8

"""
    Conekta API

    Conekta sdk

    The version of the OpenAPI document: 2.2.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class PaymentMethodCash(BaseModel):
    """
    PaymentMethodCash
    """ # noqa: E501
    type: Optional[StrictStr] = None
    object: StrictStr
    agreement: Optional[StrictStr] = Field(default=None, description="Agreement ID")
    auth_code: Optional[StrictInt] = None
    cashier_id: Optional[StrictStr] = None
    reference: Optional[StrictStr] = None
    barcode_url: Optional[StrictStr] = None
    expires_at: Optional[StrictInt] = None
    product_type: Optional[StrictStr] = Field(default=None, description="Product type, e.g. bbva_cash_in, cash_in, pespay_cash_in, etc.")
    service_name: Optional[StrictStr] = None
    store: Optional[StrictStr] = None
    store_name: Optional[StrictStr] = None
    customer_ip_address: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["type", "object", "agreement", "auth_code", "cashier_id", "reference", "barcode_url", "expires_at", "product_type", "service_name", "store", "store_name", "customer_ip_address"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PaymentMethodCash from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if auth_code (nullable) is None
        # and model_fields_set contains the field
        if self.auth_code is None and "auth_code" in self.model_fields_set:
            _dict['auth_code'] = None

        # set to None if cashier_id (nullable) is None
        # and model_fields_set contains the field
        if self.cashier_id is None and "cashier_id" in self.model_fields_set:
            _dict['cashier_id'] = None

        # set to None if store (nullable) is None
        # and model_fields_set contains the field
        if self.store is None and "store" in self.model_fields_set:
            _dict['store'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PaymentMethodCash from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "type": obj.get("type"),
            "object": obj.get("object"),
            "agreement": obj.get("agreement"),
            "auth_code": obj.get("auth_code"),
            "cashier_id": obj.get("cashier_id"),
            "reference": obj.get("reference"),
            "barcode_url": obj.get("barcode_url"),
            "expires_at": obj.get("expires_at"),
            "product_type": obj.get("product_type"),
            "service_name": obj.get("service_name"),
            "store": obj.get("store"),
            "store_name": obj.get("store_name"),
            "customer_ip_address": obj.get("customer_ip_address")
        })
        return _obj





# coding: utf-8

"""
    Conekta API

    Conekta sdk

    The version of the OpenAPI document: 2.2.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from conekta.api.events_api import EventsApi


class TestEventsApi(unittest.TestCase):
    """EventsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = EventsApi()

    def tearDown(self) -> None:
        pass

    def test_get_event(self) -> None:
        """Test case for get_event

        Get Event
        """
        pass

    def test_get_events(self) -> None:
        """Test case for get_events

        Get list of Events
        """
        pass

    def test_resend_event(self) -> None:
        """Test case for resend_event

        Resend Event
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Conekta API

    Conekta sdk

    The version of the OpenAPI document: 2.2.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from conekta.models.fiscal_entity_address import FiscalEntityAddress
from typing import Optional, Set
from typing_extensions import Self

class OrderUpdateFiscalEntityRequest(BaseModel):
    """
    Fiscal entity of the order, Currently it is a purely informative field
    """ # noqa: E501
    address: FiscalEntityAddress
    email: Optional[StrictStr] = Field(default=None, description="Email of the fiscal entity")
    name: Optional[StrictStr] = Field(default=None, description="Name of the fiscal entity")
    metadata: Optional[Dict[str, Any]] = Field(default=None, description="Metadata associated with the fiscal entity")
    phone: Optional[StrictStr] = Field(default=None, description="Phone of the fiscal entity")
    tax_id: Optional[StrictStr] = Field(default=None, description="Tax ID of the fiscal entity")
    __properties: ClassVar[List[str]] = ["address", "email", "name", "metadata", "phone", "tax_id"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of OrderUpdateFiscalEntityRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of address
        if self.address:
            _dict['address'] = self.address.to_dict()
        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict['name'] = None

        # set to None if tax_id (nullable) is None
        # and model_fields_set contains the field
        if self.tax_id is None and "tax_id" in self.model_fields_set:
            _dict['tax_id'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of OrderUpdateFiscalEntityRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "address": FiscalEntityAddress.from_dict(obj["address"]) if obj.get("address") is not None else None,
            "email": obj.get("email"),
            "name": obj.get("name"),
            "metadata": obj.get("metadata"),
            "phone": obj.get("phone"),
            "tax_id": obj.get("tax_id")
        })
        return _obj





# coding: utf-8

"""
    Conekta API

    Conekta sdk

    The version of the OpenAPI document: 2.2.0
    Contact: engineering@conekta.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class PaymentMethodCard(BaseModel):
    """
    PaymentMethodCard
    """ # noqa: E501
    type: Optional[StrictStr] = None
    object: StrictStr
    account_type: Optional[StrictStr] = Field(default=None, description="Account type of the card")
    auth_code: Optional[StrictStr] = None
    brand: Optional[StrictStr] = Field(default=None, description="Brand of the card")
    contract_id: Optional[StrictStr] = Field(default=None, description="Id sent for recurrent charges.")
    country: Optional[StrictStr] = Field(default=None, description="Country of the card")
    exp_month: Optional[StrictStr] = Field(default=None, description="Expiration month of the card")
    exp_year: Optional[StrictStr] = Field(default=None, description="Expiration year of the card")
    fraud_indicators: Optional[List[Any]] = None
    issuer: Optional[StrictStr] = Field(default=None, description="Issuer of the card")
    last4: Optional[StrictStr] = Field(default=None, description="Last 4 digits of the card")
    name: Optional[StrictStr] = Field(default=None, description="Name of the cardholder")
    customer_ip_address: Optional[StrictStr] = Field(default=None, description="Optional field used to capture the customer's IP address for fraud prevention and security monitoring purposes")
    __properties: ClassVar[List[str]] = ["type", "object", "account_type", "auth_code", "brand", "contract_id", "country", "exp_month", "exp_year", "fraud_indicators", "issuer", "last4", "name", "customer_ip_address"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PaymentMethodCard from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PaymentMethodCard from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "type": obj.get("type"),
            "object": obj.get("object"),
            "account_type": obj.get("account_type"),
            "auth_code": obj.get("auth_code"),
            "brand": obj.get("brand"),
            "contract_id": obj.get("contract_id"),
            "country": obj.get("country"),
            "exp_month": obj.get("exp_month"),
            "exp_year": obj.get("exp_year"),
            "fraud_indicators": obj.get("fraud_indicators"),
            "issuer": obj.get("issuer"),
            "last4": obj.get("last4"),
            "name": obj.get("name"),
            "customer_ip_address": obj.get("customer_ip_address")
        })
        return _obj


